/******************************************************************************

                               Copyright (c) 2011
                            Lantiq Deutschland GmbH

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

******************************************************************************/ 

#include "drv_onu_api.h"
#include "drv_onu_tse_config.h"
#include "drv_onu_ll_cop.h"
#include "drv_onu_resource_gpe_tables.h"

/*
This is the contents of the configuration space for the TSE coprocessors,
generated by SCE_Tables.xls.
For each TSE, an array is provided with a size that matches the size of the TSE
config space (TABLE<X><Y> registers).
Write the array (one 32-bit-word at a time) to TableID=0 starting with INDEX=4.
With every uint32_t, increment INDEX by 1.
*/

struct sce_table_cfg cop_tbl_cfg[] = {
	/* FID */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - was ONU_GPE_LAN_EXCEPTION_TABLE */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 2 - was ONU_GPE_ANI_EXCEPTION_TABLE, now undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 3 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 4 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* FWD */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - ONU_GPE_SHORT_FWD_HASH_TABLE */
	{ONU_GPE_COP_HASH, 0, ONU_GPE_SHORT_FWD_HASH_TABLE_SIZE, 32, 64, "ONU_GPE_SHORT_FWD_HASH_TABLE"},
	/* 2 - ONU_GPE_SHORT_FWD_TABLE_XXX */
	{ONU_GPE_COP_LLIST, 1024, ONU_GPE_SHORT_FWD_TABLE_MAC_SIZE, 128, 64, "ONU_GPE_SHORT_FWD_TABLE_XXX"},
	/* 3 - ONU_GPE_LEARNING_LIMITATION_TABLE */
	{ONU_GPE_COP_ARRAY, 5120, ONU_GPE_LEARNING_LIMITATION_TABLE_SIZE, 32, 0, "ONU_GPE_LEARNING_LIMITATION_TABLE"},
	/* 4 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_GPE_SHORT_FWD_ALT"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* TAG */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - ONU_GPE_TAGGING_FILTER_TABLE */
	{ONU_GPE_COP_VARRAY, 0, ONU_GPE_TAGGING_FILTER_TABLE_SIZE, 64, 0, "ONU_GPE_TAGGING_FILTER_TABLE"},
	/* 2 - ONU_GPE_VLAN_TABLE */
	{ONU_GPE_COP_LIST, 256, ONU_GPE_VLAN_TABLE_SIZE, 32, 16, "ONU_GPE_VLAN_TABLE"},
	/* 3 - ONU_GPE_ETHERTYPE_FILTER_TABLE */
	{ONU_GPE_COP_LIST, 1280, ONU_GPE_ETHERTYPE_FILTER_TABLE_SIZE, 32, 16, "ONU_GPE_ETHERTYPE_FILTER_TABLE"},
	/* 4 - ONU_GPE_COUNTER_TABLE */
	{ONU_GPE_COP_ARRAY, 1344, ONU_GPE_COUNTER_TABLE_SIZE, 32, 0, "ONU_GPE_COUNTER_TABLE"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* TBL */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - ONU_GPE_DS_GEM_PORT_TABLE */
	{ONU_GPE_COP_VARRAY, 0, ONU_GPE_DS_GEM_PORT_TABLE_SIZE, 128, 0, "ONU_GPE_DS_GEM_PORT_TABLE"},
	/* 2 - undef */
	{ONU_GPE_COP_LIST, 0, ONU_GPE_MAC_FILTER_TABLE_SIZE, 64, 0, "ONU_GPE_MAC_FILTER_TABLE"},
	/* 3 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 4 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* MSF */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - ONU_GPE_LONG_FWD_HASH_TABLE */
	{ONU_GPE_COP_HASH, 0, ONU_GPE_LONG_FWD_HASH_TABLE_SIZE, 32, 160, "ONU_GPE_LONG_FWD_HASH_TABLE"},
	/* 2 - ONU_GPE_LONG_FWD_TABLE_IPV6_XXX */
	{ONU_GPE_COP_LLIST, 1024, ONU_GPE_LONG_FWD_TABLE_IPV6_SIZE, 256, 160, "ONU_GPE_LONG_FWD_TABLE_IPV6_XXX"},
	/* 3 - ONU_GPE_DS_MC_IPV4_SOURCE_FILTER_TABLE */
	{ONU_GPE_COP_LIST, 2048, ONU_GPE_DS_MC_IPV4_SOURCE_FILTER_TABLE_SIZE, 64, 32, "ONU_GPE_DS_MC_IPV4_SOURCE_FILTER_TABLE"},
	/* 4 - ONU_GPE_DS_MC_IPV6_SOURCE_FILTER_TABLE */
	{ONU_GPE_COP_LIST, 3072, ONU_GPE_DS_MC_IPV6_SOURCE_FILTER_TABLE_SIZE, 256, 128, "ONU_GPE_DS_MC_IPV6_SOURCE_FILTER_TABLE"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* EXT */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - ONU_GPE_US_GEM_PORT_TABLE */
	{ONU_GPE_COP_VARRAY, 0, ONU_GPE_US_GEM_PORT_TABLE_SIZE, 32, 0, "ONU_GPE_US_GEM_PORT_TABLE"},
	/* 2 - ONU_GPE_FID_ASSIGNMENT_TABLE */
	{ONU_GPE_COP_LLIST, 256, ONU_GPE_FID_ASSIGNMENT_TABLE_SIZE, 64, 32, "ONU_GPE_FID_ASSIGNMENT_TABLE"},
	/* 3 - ONU_GPE_FID_HASH_TABLE */
	{ONU_GPE_COP_HASH, 768, ONU_GPE_FID_HASH_TABLE_SIZE, 32, 32, "ONU_GPE_FID_HASH_TABLE"},
	/* 4 - ONU_GPE_EXTENDED_VLAN_TABLE */
	{ONU_GPE_COP_VARRAY, 1792, ONU_GPE_EXTENDED_VLAN_TABLE_SIZE, 64, 0, "ONU_GPE_EXTENDED_VLAN_TABLE"},
	/* 5 - ONU_GPE_VLAN_RULE_TABLE */
	{ONU_GPE_COP_LIST, 2048, ONU_GPE_VLAN_RULE_TABLE_SIZE, 64, 96, "ONU_GPE_VLAN_RULE_TABLE"},
	/* 6 - ONU_GPE_VLAN_TREATMENT_TABLE */
	{ONU_GPE_COP_VARRAY, 4096, ONU_GPE_VLAN_TREATMENT_TABLE_SIZE, 64, 0, "ONU_GPE_VLAN_TREATMENT_TABLE"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_GPE_FID_ASSIGNMENT_MASKED"},

	/* TBM */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 2 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 3 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 4 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},

	/* LOOP */

	/* 0 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 1 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 2 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 3 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 4 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 5 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 6 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "ONU_UNDEF"},
	/* 7 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, NULL}
};

/* copied following configurations from SCE_Tables.xls */
const struct sce_table_cfg pe_tbl_cfg[] = {
	/* 0 - ONU_GPE_CONSTANTS_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_CONSTANTS_TABLE_SIZE, ONU_GPE_CONSTANTS_TABLE_ENTRY_SIZE, 0, "ONU_GPE_CONSTANTS_TABLE"},
	/* 1 - ONU_GPE_BRIDGE_PORT_TABLE */
	{ONU_GPE_COP_VARRAY, 0, ONU_GPE_BRIDGE_PORT_TABLE_SIZE, ONU_GPE_BRIDGE_PORT_TABLE_ENTRY_SIZE, 0, "ONU_GPE_BRIDGE_PORT_TABLE"},
	/* 2 - ONU_GPE_PMAPPER_TABLE */
	{ONU_GPE_COP_VARRAY, 0, ONU_GPE_PMAPPER_TABLE_SIZE, ONU_GPE_PMAPPER_TABLE_ENTRY_SIZE, 0, "ONU_GPE_PMAPPER_TABLE"},
	/* 3 - ONU_GPE_LAN_PORT_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_LAN_PORT_TABLE_SIZE, ONU_GPE_LAN_PORT_TABLE_ENTRY_SIZE, 0, "ONU_GPE_LAN_PORT_TABLE"},
	/* 4 - ONU_GPE_ENQUEUE_TABLE_ID */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_ENQUEUE_TABLE_SIZE, ONU_GPE_ENQUEUE_TABLE_ENTRY_SIZE, 0, "ONU_GPE_ENQUEUE_TABLE"},
	/* 5 - ONU_GPE_PCP_DECODING_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_PCP_DECODING_TABLE_SIZE, ONU_GPE_PCP_DECODING_TABLE_ENTRY_SIZE, 0, "ONU_GPE_PCP_DECODING_TABLE"},
	/* 6 - ONU_GPE_DSCP_DECODING_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_DSCP_DECODING_TABLE_SIZE, ONU_GPE_DSCP_DECODING_TABLE_ENTRY_SIZE, 0, "ONU_GPE_DSCP_DECODING_TABLE"},
	/* 7 - ONU_GPE_PCP_ENCODING_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_PCP_ENCODING_TABLE_SIZE, ONU_GPE_PCP_ENCODING_TABLE_ENTRY_SIZE, 0, "ONU_GPE_PCP_ENCODING_TABLE"},
	/* 8 - ONU_GPE_DSCP_ENCODING_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_DSCP_ENCODING_TABLE_SIZE, ONU_GPE_DSCP_ENCODING_TABLE_ENTRY_SIZE, 0, "ONU_GPE_DSCP_ENCODING_TABLE"},
	/* 9 - ONU_GPE_REDIRECTION_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_REDIRECTION_TABLE_SIZE, ONU_GPE_REDIRECTION_TABLE_ENTRY_SIZE, 0, "ONU_GPE_REDIRECTION_TABLE"},
	/* 10 - undef */
	{ONU_GPE_COP_UNDEF, 0, 0, 0, 0, "UNDEFINED"},
	/* 11 - ONU_GPE_ACL_FILTER_TABLE */
	{ONU_GPE_COP_LIST, 0, ONU_GPE_ACL_FILTER_TABLE_SIZE, ONU_GPE_ACL_FILTER_TABLE_ENTRY_SIZE, 0, "ONU_GPE_ACL_FILTER_TABLE"},
	/* 12 - ONU_GPE_BRIDGE_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_BRIDGE_TABLE_SIZE, ONU_GPE_BRIDGE_TABLE_ENTRY_SIZE, 0, "ONU_GPE_BRIDGE_TABLE"},
	/* 13 - ONU_GPE_STATUS_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_STATUS_TABLE_SIZE, ONU_GPE_STATUS_TABLE_ENTRY_SIZE, 0, "ONU_GPE_STATUS_TABLE"},
	/* 14 - ONU_GPE_EXCEPTION_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_EXCEPTION_TABLE_SIZE, ONU_GPE_EXCEPTION_TABLE_ENTRY_SIZE, 0, "ONU_GPE_EXCEPTION_TABLE"},
	/* 15 - ONU_GPE_ETHERTYPE_EXCEPTION_TABLE */
	{ONU_GPE_COP_ARRAY, 0, ONU_GPE_ETHERTYPE_EXCEPTION_TABLE_SIZE, ONU_GPE_ETHERTYPE_EXCEPTION_TABLE_ENTRY_SIZE, 0, "ONU_GPE_ETHERTYPE_EXCEPTION_TABLE"}
};

uint32_t sce_table_cfg_size = ARRAY_SIZE(pe_tbl_cfg);

