/******************************************************************************

                               Copyright (c) 2011
                            Lantiq Deutschland GmbH

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

******************************************************************************/ 
#ifndef _drv_onu_tse_config_h
#define _drv_onu_tse_config_h

/** \addtogroup ONU_MAPI_REFERENCE_INTERNAL
   @{
*/

/** \addtogroup ONU_SCE_INTERNAL GPE - SCE Interface
   @{
*/

/*
   This is the table definition for use by the ONU Driver, generated by
   SCE_Tables.xls.

   Purposes:
   The table initialization routine derives index ranges and init values from
   this structure.

   Table access functions derive the appropriate key length from this structure.

   Definition of global table ID, depending on the location of the table:
      if COP  then table = COPID<<3 + TableID  // 0...63
      if PE  then table = 64 + TableID  //64...95

   During table initialization, step through the table_cfg array:

   For type = 15 (UNDEFINED or RESERVED), do nothing.

   For type = 2 (LIST), initialize all entries with
   0 + 1<<(entry_width-2).
   This will set the END bit, which is next to the MSB.

   For type = 3 (LLIST), initialize all entries with
   0 + (index+1)<<(entry_width-16).
   This will set the NEXT pointer such that each entry is linked to the
   following entry.

   Initialize the last entry (index=size) with 0 + 1<<(entry_width-2)
   This will set the END bit, which is next to the MSB.
   Together with the table's AUX pointer (configured to zero) this procedure
   forms the table's freelist.

   For all other table_types, initialize all entries with 0.
*/

/** Table configuration structure */
struct sce_table_cfg {
	/** Table type */
	uint32_t type;
	/** Table base address (for COP tables) */
	uint32_t base;
	/** Number of table entries */
	uint32_t size;
	/** Table entry width in bits */
	uint32_t entry_width;
	/** Table entry key length */
	uint32_t key_len;
	/** Table name */
	const char *name;
};

/** SCE tables configuration */
extern const struct sce_table_cfg pe_tbl_cfg[];

/** COP tables configuration */
extern struct sce_table_cfg cop_tbl_cfg[];

/** Number of entries in \ref sce_table_cfg */
extern uint32_t sce_table_cfg_size;

/** Number of entries in \ref cop_tbl_cfg */
#define COP_TABLE_CFG_SIZE		(ONU_GPE_NUMBER_OF_COP * 8)

extern const uint32_t fid_config[];
extern const uint32_t fwd_config[];
extern const uint32_t tag_config[];
extern const uint32_t tbl_config[];
extern const uint32_t msf_config[];
extern const uint32_t ext_config[];

/*! @} */

/*! @} */

#endif
